<?php
/**
 * Postscript MediaWiki extension  version 1.0.2
 *	for details please see: https://www.mediawiki.org/wiki/Extension:Postscript
 *
 * Copyright (c) 2023 Kimagurenote https://kimagurenote.net/
 * License: Revised BSD license http://opensource.org/licenses/BSD-3-Clause
 *
 * Function:
 *	Mediawiki extension what add text or script post all artices.
 *
 * Dependency:
 *	MediaWiki 1.25+
 *	This extension registrated wfLoadExtension() only.
 *	https://www.mediawiki.org/wiki/Manual:Extension_registration
 *
 * History:
 * 2023.08.15 Version 1.0.2
 *	check page exist and redirect
 * 2023.08.02 Version 1.0.1
 *	change using hook ContentAlterParserOutput→BeforePageDisplay because avoid to conflict with Extension:Popups.
 * 2023.08.01 Version 1.0.0
 *	1st version
 *
 * @file
 * @ingroup Extensions
 * @author Kimagurenote
 * @copyright © 2023 Kimagurenote
 * @license The BSD 3-Clause License
 */

if( !defined( 'MEDIAWIKI' ) ) {
	echo( "This file is an extension to the MediaWiki software and cannot be used standalone.\n" );
	die( 1 );
}


class Postscript {

	/**
	 * @param OutputPage $out
	 * @param Skin $skin
	 * return void
	 * https://www.mediawiki.org/wiki/Manual:Hooks/BeforePageDisplay
	 *
	 * Hook that allows last minute changes to the output page, e.g.
	 * adding of CSS or Javascript by extensions, adding CSP sources.
	 * https://doc.wikimedia.org/mediawiki-core/master/php/OutputPage_8php_source.html#l02917
	 */
	public static function onBeforePageDisplay( OutputPage $out, Skin $skin ) {
		global $wgPostscriptText;

		/* check page exist */
		if( !$skin->getTitle()->exists() ) {
			return;
		};

		/* check redirect */
		if( !empty( $out->getRedirect() ) ) {
			return;
		};
		/*
		if( !empty( $skin->getArticle()->getPage()->followRedirect() ) ) {
			return;
		};	*/

		/* parameter check */
		if( empty( $wgPostscriptText ) ) {
			return;
		};

		/* get namespace */
		$ns = $skin->getTitle()->getNamespace();

		/* process only for namespace NS_MAIN if served a string value */
		if( is_string( $wgPostscriptText ) ) {
			if( $ns != NS_MAIN ) {
				/* NS_MAIN 以外では処理しない */
				return;
			}

			$out->addHTML( "\n<!-- Extension:Postscript -->\n" . $wgPostscriptText . "\n<!-- /Extension:Postscript -->\n" );

			return;
		};

		/* Check value for this namespace */
		// https://www.mediawiki.org/wiki/Manual:Namespace_constants
		if( empty( $wgPostscriptText[$ns] ) ) {
			return;
		}

		$out->addHTML( "\n<!-- Extension:Postscript -->\n" . $wgPostscriptText[$ns] . "\n<!-- /Extension:Postscript -->\n" );

		return;
	}
}
?>
